<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Goods\Repository;

use Doctrine\ORM\EntityRepository;
use Doctrine\ORM\Query\Expr\Join;
use Goods\Entity\Goods;
use Goods\Entity\GoodsContent;
use Goods\Entity\GoodsGroupPrice;
use Goods\Entity\GoodsImage;
use Goods\Entity\GoodsSalesRecord;
use Goods\Entity\GoodsSpecTagGoods;
use PluginGroupShow\Entity\GroupShow;

class GoodsSpecTagGoodsRepository extends EntityRepository
{
    /**
     * 特定标签商品
     * @param $specTagId
     * @return mixed
     */
    public function findSpecTagGoods($specTagId)
    {
        $query = $this->getEntityManager()->createQueryBuilder()
            ->select('s', 'g.goodsState')
            ->addSelect("(SELECT c.goodsName FROM ".GoodsContent::class." AS c WHERE c.goodsId=g.goodsId AND c.languageCode='".SHOP_FONT_LANGUAGE."') AS goodsName")
            ->from(GoodsSpecTagGoods::class, 's')
            ->innerJoin(Goods::class, 'g', Join::WITH, 'g.goodsId = s.goodsId')
            ->where('s.specTagId = :specTagId')->setParameter('specTagId', $specTagId)
            ->orderBy('s.specTagGoodsSort', 'ASC')
            ->addOrderBy('s.goodsId', 'DESC');

        return $query->getQuery()->getResult();
    }

    /*=============================================前台使用=============================================*/
    /**
     * 通过特定标签和模板检索商品
     * @param $specTagCode
     * @param $templateCode
     * @param $userGroupId
     * @param $languageCode
     * @return float|int|mixed|string
     */
    public function findSpecTagGoodsByTagAndTemplate($specTagCode, $templateCode, $userGroupId, $languageCode)
    {
        $query = $this->getEntityManager()->createQueryBuilder()
            ->select('s',
                'g.virtualSales', 'g.classId', 'g.goodsPrice', 'g.goodsMarketPrice', 'g.goodsWeight', 'g.goodsWeightUnit',
                'i.goodsThumbnailImage',
                'r.goodsSalesNum',
                'c.goodsName', 'c.goodsDescription'
            )
            //->addSelect("(SELECT c.goodsName FROM ".GoodsContent::class." AS c WHERE c.goodsId=g.goodsId AND c.languageCode='".$languageCode."') AS goodsName")
            ->from(GoodsSpecTagGoods::class, 's')
            ->innerJoin(Goods::class, 'g', Join::WITH, 'g.goodsId = s.goodsId')
            ->innerJoin(GoodsSalesRecord::class, 'r', Join::WITH, 'g.goodsId =  r.goodsId')
            ->innerJoin(GoodsContent::class, 'c', Join::WITH, 'g.goodsId = c.goodsId')
            ->leftJoin(GoodsImage::class, 'i', Join::WITH, 'g.goodsImageId = i.goodsImageId')
            ->where('s.specTagCode = :specTagCode')->setParameter('specTagCode', $specTagCode)
            ->andWhere('s.templateCode = :templateCode')->setParameter('templateCode', $templateCode)
            ->andWhere('c.languageCode = :languageCode')->setParameter('languageCode', $languageCode)
            ->andWhere('g.goodsState=1')
            ->orderBy('s.specTagGoodsSort', 'ASC')
            ->addOrderBy('s.goodsId', 'DESC');

        //如果会员组存在，则获取会员组价格
        if($userGroupId > 0) $query->addSelect('(SELECT p.userGroupPrice FROM '.GoodsGroupPrice::class.' AS p WHERE p.goodsId=g.goodsId AND p.userGroupId='.$userGroupId.') AS goodsGroupPrice');

        //加入对客户组查看权限的支持
        if (class_exists(GroupShow::class)) {
            $query->innerJoin(GroupShow::class, 'ss', Join::WITH, 'ss.goodsId=g.goodsId')
                ->andWhere('ss.userGroupId = :userGroupId')->setParameter('userGroupId', intval($userGroupId));
        }

        return $query->getQuery()->getResult();
    }
}