<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Operation\Form;

use Admin\Data\Config;
use Laminas\Form\Form;

class CouponCodeRuleForm extends Form
{
    private $editState;

    public function __construct($editState = false, $name = 'coupon-code-form', $options = [])
    {
        parent::__construct($name, $options);

        $this->setAttribute('method', 'post');
        $this->setAttribute('class', 'form-horizontal');

        $this->editState = $editState;

        $this->addElements();
        $this->addInputFilter();
    }

    protected function addElements()
    {
        foreach (SHOP_LANGUAGE as $language) {
            $this->add([
                'type'  => 'text',
                'name'  => 'couponCodeTitle'.$language,
                'attributes'    => [
                    'id'    => 'couponCodeTitle'.$language,
                    'class' => 'form-control'
                ]
            ]);
        }

        $this->add([
            'type'  => 'text',
            'name'  => 'couponCodeStartTime',
            'attributes'    => [
                'id'    => 'couponCodeStartTime',
                'class' => 'form-control'
            ]
        ]);

        $this->add([
            'type'  => 'text',
            'name'  => 'couponCodeEndTime',
            'attributes'    => [
                'id'    => 'couponCodeEndTime',
                'class' => 'form-control'
            ]
        ]);

        if (!$this->editState) {
            $this->add([
                'type'  => 'number',
                'name'  => 'codeNum',
                'attributes'    => [
                    'id'    => 'codeNum',
                    'class' => 'form-control',
                    'value' => 50,
                    'min'   => 1,
                    'max'   => Config::CREATE_RECHARGE_CODE_MAX_NUM
                ]
            ]);
        }

        $this->add([
            'type'  => 'number',
            'name'  => 'userUseNum',
            'attributes'    => [
                'id'    => 'userUseNum',
                'class' => 'form-control',
                'value' => 1,
                'min'   => 1
            ]
        ]);

        $this->add([
            'type'  => 'checkbox',
            'name'  => 'couponCodeState',
            'attributes'    => [
                'id'    => 'couponCodeState',
                'value' => 1
            ]
        ]);

        $this->add([
            'type'  => 'number',
            'name'  => 'shoppingAmount',
            'attributes'    => [
                'id'    => 'shoppingAmount',
                'class' => 'form-control',
                'value' => 1,
                'min'   => 1
            ]
        ]);

        $this->add([
            'type'  => 'number',
            'name'  => 'shoppingDiscount',
            'attributes'    => [
                'id'    => 'shoppingDiscount',
                'class' => 'form-control',
                'value' => 1,
                'min'   => 1
            ]
        ]);

        $this->add([
            'type'  => 'select',
            'name'  => 'couponCodeUserType',
            'attributes'    => [
                'id'            => 'couponCodeUserType',
                'class'         => 'form-control'
            ]
        ]);

        $this->add([
            'type'  => 'multiCheckbox',
            'name'  => 'userGroup',
            'options'    => [
                'label_attributes' => [
                    'class' => 'checkbox-inline'
                ]
            ]
        ]);

        $this->add([
            'type'  => 'select',
            'name'  => 'couponCodeGoodsType',
            'attributes'    => [
                'id'            => 'couponCodeGoodsType',
                'class'         => 'form-control'
            ]
        ]);

        $this->add([
            'type'  => 'multiCheckbox',
            'name'  => 'goodsClass'
        ]);

        $this->add([
            'type'  => 'multiCheckbox',
            'name'  => 'goodsBrand'
        ]);
    }

    protected function addInputFilter()
    {
        $inputFilter = $this->getInputFilter();

        foreach (SHOP_LANGUAGE as $language) {
            $inputFilter->add([
                'name'      => 'couponCodeTitle'.$language,
                'required'  => true,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ]
            ]);
        }

        $inputFilter->add([
            'name'      => 'couponCodeStartTime',
            'required'  => false,
            'filters'   => [
                ['name' => 'StringTrim'],
                ['name' => 'StripTags']
            ]
        ]);

        $inputFilter->add([
            'name'      => 'couponCodeEndTime',
            'required'  => false,
            'filters'   => [
                ['name' => 'StringTrim'],
                ['name' => 'StripTags']
            ]
        ]);

        if (!$this->editState) {
            $inputFilter->add([
                'name'      => 'codeNum',
                'required'  => true,
                'filters'   => [
                    ['name' => 'ToInt']
                ],
                'validators'=> [
                    [
                        'name'      => 'GreaterThan',
                        'options'   => [
                            'min'   => 0,
                            'max'   => Config::CREATE_RECHARGE_CODE_MAX_NUM
                        ]
                    ]
                ]
            ]);
        }

        $inputFilter->add([
            'name'      => 'userUseNum',
            'required'  => true,
            'filters'   => [
                ['name' => 'ToInt']
            ],
            'validators'=> [
                [
                    'name'      => 'GreaterThan',
                    'options'   => [
                        'min'   => 0
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'couponCodeState',
            'required'  => false,
            'validators'=> [
                [
                    'name'      => 'InArray',
                    'options'   => [
                        'haystack'  => [0, 1]
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'shoppingAmount',
            'required'  => true,
            'filters'   => [
                ['name' => 'ToInt']
            ],
            'validators'=> [
                [
                    'name'      => 'GreaterThan',
                    'options'   => [
                        'min'   => 0,
                        'inclusive' => true
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'shoppingDiscount',
            'required'  => true,
            'filters'   => [
                ['name' => 'ToInt']
            ],
            'validators'=> [
                [
                    'name'      => 'GreaterThan',
                    'options'   => [
                        'min'   => 0,
                        'inclusive' => true
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'userGroup',
            'required'  => false,
            'filters'   => [
                ['name' => 'ToInt']
            ]
        ]);

        $inputFilter->add([
            'name'      => 'goodsClass',
            'required'  => false,
            'filters'   => [
                ['name' => 'ToInt']
            ]
        ]);

        $inputFilter->add([
            'name'      => 'goodsBrand',
            'required'  => false,
            'filters'   => [
                ['name' => 'ToInt']
            ]
        ]);
    }
}