<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Shop\Validator;

use Laminas\I18n\Translator\Translator;
use Laminas\Session\Container;
use Laminas\Validator\AbstractValidator;

class PhoneCaptchaValidator extends AbstractValidator
{
    const NOT_SCALAR    = 'notScalar';
    const ERROR_PHONE   = 'errorPhone';
    const ERROR_CAPTCHA = 'errorCaptcha';
    const ERROR_OVERTIME = 'errorOvertime';

    private $dbshopSession;

    protected $messageTemplates = [];

    public function __construct($options = null)
    {
        $this->dbshopSession = new Container('dbshopSession');

        $trans = new Translator();
        $this->messageTemplates = [
            self::NOT_SCALAR    => $trans->translate("这不是一个标准输入值"),
            self::ERROR_PHONE   => $trans->translate("手机号码与获取验证码的手机号码不同"),
            self::ERROR_CAPTCHA => $trans->translate("验证码错误"),
            self::ERROR_OVERTIME=> $trans->translate("验证码超时")
        ];

        parent::__construct($options);
    }

    public function isValid($value, $context=null)
    {
        if(!is_scalar($value)) {
            $this->error(self::NOT_SCALAR);
            return false;
        }

        //判断是否超时
        if (($this->dbshopSession->offsetExists('expiredTime') && $this->dbshopSession->offsetGet('expiredTime') < time()) || !$this->dbshopSession->offsetExists('expiredTime')) {
            $this->dbshopSession->offsetUnset('phoneCaptcha');
            $this->dbshopSession->offsetUnset('phoneNumber');
            $this->dbshopSession->offsetUnset('expiredTime');
            $this->error(self::ERROR_OVERTIME);
            return false;
        }

        if (empty($context['userPhone']) || !$this->dbshopSession->offsetExists('phoneNumber') || ($this->dbshopSession->offsetExists('phoneNumber') && $this->dbshopSession->offsetExists('phoneNumber') != $context['userPhone'])) {
            $this->error(self::ERROR_PHONE);
            return false;
        }

        if (!$this->dbshopSession->offsetExists('phoneCaptcha') || $this->dbshopSession->offsetGet('phoneCaptcha') != $value) {
            $this->error(self::ERROR_CAPTCHA);
            return false;
        }

        return true;
    }
}